pub enum Authentication<'a> {
Bot {
token: &'a str,
},
User {
session_token: &'a str,
},
}Expand description
A value that can be used to authenticate on the websocket, either as a bot or as a non-bot user.
Variants