Connection

Struct Connection 

pub struct Connection(/* private fields */);
A websocket connection.

Implementations

Source

impl Connection

pub async fn connect<'a>(auth: impl Into<Authentication<'a>>) -> Result<Self>

Connects to the websocket, and authenticates, returning the socket or an error if it failed.

pub async fn connect_with_url<'a>( auth: impl Into<Authentication<'a>>, url: &str, ) -> Result<Self>

Connects to the websocket on the specified url, and authenticates, returning the socket or an error if it failed.

Use if connecting to a self-hosted instance of revolt; otherwise use Self::connect.

pub async fn run<C, H>(self, ctx: C, handler: H) -> Result
where C: Context, H: RawEventHandler<Context = C>,

Runs the “main loop”, listening for events on the websocket and spawning tokio tasks to handle them, cloning the context, and giving it a messanger.

If you intend to implement this yourself, you can use Connection::get_event to get events and Connection::hb to “heartbeat”(send a ping message to the server so it doesn’t close the socket).

pub async fn hb(&mut self) -> Result

Sends a ping message to the server, so it doesn’t close the connection.

pub async fn get_event(&mut self) -> Result<ServerToClientEvent>

Gets the next event from the server.

pub async fn start_typing(&mut self, channel: ChannelId) -> Result

Sends a ClientToServerEvent::BeginTyping event, for the given channel.

Has a timeout of ~3 seconds, so if you want it to display “… is typing” for longer than that, you have to call it again.

pub async fn stop_typing(&mut self, channel: ChannelId) -> Result

Sends a ClientToServerEvent::EndTyping event, for the given channel.

pub async fn close(self) -> Result

Closes the websocket.